@@ -19,6 +19,11 @@ import re
 
 from ._compat import text_type
 
+OBFUSCATION_KEYWORDS = ('PASSWORD', 'SECRET', 'TOKEN',)
+OBFUSCATION_RE = re.compile(r'((password|secret|token):\s*)(\S+)',
+                            flags=re.IGNORECASE | re.MULTILINE)
+OBFUSCATED_SECRET = 'x' * 16
+
 
 def get_field_value_recursive(logger, properties, path):
     if not path:
@@ -195,19 +200,18 @@ def obfuscate_passwords(obj):
     any passwords, original is returned and deepcopy never performed.
     """
     if isinstance(obj, (text_type, bytes,)):
-        return re.sub(r'(password:\s*)(\S+)', '\\1{0}'.format('x' * 16), obj,
-                      flags=re.MULTILINE | re.IGNORECASE)
+        return OBFUSCATION_RE.sub('\\1{0}'.format(OBFUSCATED_SECRET), obj)
     if isinstance(obj, list):
         return [obfuscate_passwords(elem) for elem in obj]
     if not isinstance(obj, dict):
         return obj
     result = obj
     for k, v in list(result.items()):
-        if k.upper() == 'PASSWORD':
+        if any(x for x in OBFUSCATION_KEYWORDS if x in k.upper()):
             a_copy = deepcopy(result)
-            a_copy[k] = 'x' * 16
+            a_copy[k] = OBFUSCATED_SECRET
             result = a_copy
-        if isinstance(v, (dict, list, )):
+        if isinstance(v, (dict, list,)):
             obfuscated_v = obfuscate_passwords(v)
             if obfuscated_v is not v:
                 a_copy = deepcopy(result)
