@@ -27,7 +27,8 @@ from cloudify_rest_sdk import LOGGER_NAME
 from cloudify_common_sdk.filters import (
     translate_and_save,
     shorted_text,
-    render_template
+    render_template,
+    obfuscate_passwords,
 )
 from cloudify_common_sdk.exceptions import (
     RecoverableStatusCodeCodeException,
@@ -44,7 +45,8 @@ TEMPLATE_PROPERTY_RETRY_ON_CONNECTION_ERROR = 'retry_on_connection_error'
 #  request_props (port, ssl, verify, hosts )
 def process(params, template, request_props, prerender=False,
             resource_callback=False):
-    logger.info('Template:\n{}'.format(shorted_text(template)))
+    logger.info(
+        'Template:\n{}'.format(shorted_text(obfuscate_passwords(template))))
     if prerender:
         rendered_call = render_template(template, params)
         template_yaml = yaml.load(rendered_call)
@@ -58,7 +60,8 @@ def process(params, template, request_props, prerender=False,
 
     for call in template_yaml['rest_calls']:
         call_with_request_props = request_props.copy()
-        logger.debug('Call: {}'.format(shorted_text(call)))
+        logger.debug(
+            'Call: {}'.format(shorted_text(obfuscate_passwords(call))))
         # enrich params with items stored in runtime props by prev calls
         params.update(result_properties)
         if not prerender:
@@ -69,7 +72,8 @@ def process(params, template, request_props, prerender=False,
             rendered_call = render_template(call, params)
             call = ast.literal_eval(rendered_call)
         calls.append(call)
-        logger.debug('Rendered call: {}'.format(shorted_text(call)))
+        logger.debug('Rendered call: {}'.format(
+            shorted_text(obfuscate_passwords(call))))
         call_with_request_props.update(call)
 
         # client/server side certification check
@@ -104,7 +108,8 @@ def process(params, template, request_props, prerender=False,
 
 
 def _send_request(call, resource_callback=None):
-    logger.debug('Request props: {}'.format(shorted_text(call)))
+    logger.debug(
+        'Request props: {}'.format(shorted_text(obfuscate_passwords(call))))
     port = call['port']
     ssl = call['ssl']
     if port == -1:
@@ -225,7 +230,8 @@ def _send_request(call, resource_callback=None):
 
 def _process_response(response, call, store_props):
     logger.debug('Process Response: {}'.format(shorted_text(response)))
-    logger.debug('Call: {}'.format(shorted_text(call)))
+    logger.debug(
+        'Call: {}'.format(shorted_text(obfuscate_passwords(call))))
     logger.debug('Store props: {}'.format(shorted_text(store_props)))
     logger.debug('Store headers: {}'.format(shorted_text(response.headers)))
     translation_version = call.get('translation_format', 'auto')
@@ -266,7 +272,7 @@ def _process_response(response, call, store_props):
         else:  # XML
             json = xmltodict.parse(response.text)
             logger.debug('XML transformed to dict: {}'
-                         .format(shorted_text(json)))
+                         .format(shorted_text(obfuscate_passwords(json))))
 
         _check_response(json, call.get('nonrecoverable_response'), False)
         _check_response(json, call.get('response_expectation'), True)
@@ -288,10 +294,12 @@ def _process_response(response, call, store_props):
 def _check_response(json, response, is_recoverable):
     if not is_recoverable:
         logger.debug('Check response (nonrecoverable) in json: {} by {}'
-                     .format(shorted_text(json), repr(response)))
+                     .format(shorted_text(obfuscate_passwords(json)),
+                             repr(response)))
     else:
         logger.debug('Check response (recoverable) in json: {} by {}'
-                     .format(shorted_text(json), repr(response)))
+                     .format(shorted_text(obfuscate_passwords(json)),
+                             repr(response)))
 
     if not response:
         return
